==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/JDBCTunnelConfigResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for JDBCTunnelConfig
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class JDBCTunnelConfigResponseProjection extends GraphQLResponseProjection {

    public JDBCTunnelConfigResponseProjection() {
    }

    @Override
    public JDBCTunnelConfigResponseProjection all$() {
        return all$(3);
    }

    @Override
    public JDBCTunnelConfigResponseProjection all$(int maxDepth) {
        this.url();
        this.username();
        this.password();
        this.typename();
        return this;
    }

    public JDBCTunnelConfigResponseProjection url() {
        return url(null);
    }

    public JDBCTunnelConfigResponseProjection url(String alias) {
        fields.add(new GraphQLResponseField("url").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection username() {
        return username(null);
    }

    public JDBCTunnelConfigResponseProjection username(String alias) {
        fields.add(new GraphQLResponseField("username").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection password() {
        return password(null);
    }

    public JDBCTunnelConfigResponseProjection password(String alias) {
        fields.add(new GraphQLResponseField("password").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection typename() {
        return typename(null);
    }

    public JDBCTunnelConfigResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/JDBCTunnelConfigResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for JDBCTunnelConfig
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class JDBCTunnelConfigResponseProjection extends GraphQLResponseProjection {

    public JDBCTunnelConfigResponseProjection() {
    }

    @Override
    public JDBCTunnelConfigResponseProjection all$() {
        return all$(3);
    }

    @Override
    public JDBCTunnelConfigResponseProjection all$(int maxDepth) {
        this.url();
        this.username();
        this.password();
        this.typename();
        return this;
    }

    public JDBCTunnelConfigResponseProjection url() {
        return url(null);
    }

    public JDBCTunnelConfigResponseProjection url(String alias) {
        fields.add(new GraphQLResponseField("url").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection username() {
        return username(null);
    }

    public JDBCTunnelConfigResponseProjection username(String alias) {
        fields.add(new GraphQLResponseField("username").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection password() {
        return password(null);
    }

    public JDBCTunnelConfigResponseProjection password(String alias) {
        fields.add(new GraphQLResponseField("password").alias(alias));
        return this;
    }

    public JDBCTunnelConfigResponseProjection typename() {
        return typename(null);
    }

    public JDBCTunnelConfigResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
